#  _Logger.py
#  Copyright (C) 2019 University of Waikato, Hamilton, New Zealand
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
import sys


class Logger:
    """
    Class implementing equivalent functionality to java's
    java.util.logging.Logger class.
    """
    def __init__(self, name: str):
        self.__name = name

    @staticmethod
    def get_logger(name: str) -> 'Logger':
        # TODO
        return Logger(name)

    @staticmethod
    def warning(message: str):
        print(message, file=sys.stderr)

    @staticmethod
    def info(message: str):
        print(message, file=sys.stdout)
